@@ -1,13 +1,12 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
-import codecs
 import os
 import re
 import subprocess
 
 
 def cffi_version():
-    with codecs.open('lib_pypy/cffi/__init__.py', encoding='UTF-8') as f:
+    with open('lib_pypy/cffi/__init__.py', encoding='UTF-8') as f:
         for line in f:
             m = re.match(r'^__version__ = "([0-9.]+)"$', line)
             if m:
@@ -16,7 +15,7 @@ def cffi_version():
 
 
 def target_version():
-    with codecs.open('lib_pypy/cffi/recompiler.py', encoding='UTF-8') as f:
+    with open('lib_pypy/cffi/recompiler.py', encoding='UTF-8') as f:
         for line in f:
             m = re.match(r'^VERSION_CHAR16CHAR32 = (0x[0-9A-F]+)$', line)
             if m:
@@ -26,8 +25,8 @@ def target_version():
 
 def backend_supported_versions():
     versions = {}
-    with codecs.open('pypy/module/_cffi_backend/cffi1_module.py',
-                     encoding='UTF-8') as f:
+    with open('pypy/module/_cffi_backend/cffi1_module.py',
+              encoding='UTF-8') as f:
         for line in f:
             m = re.match(r'^VERSION_(MIN|MAX) *= (0x[0-9A-F]+)$',
                          line)
@@ -57,18 +56,18 @@ subst = {
     'max': versions[1],
     'target': target,
 }
-with codecs.open('debian/pypy3-lib.substvars', 'a', encoding='UTF-8') as f:
+with open('debian/pypy3-lib.substvars', 'a', encoding='UTF-8') as f:
     f.write('cffi:Provides=pypy3-cffi (= {cffi}), '
             'pypy3-cffi-backend-api-min (= {min}), '
             'pypy3-cffi-backend-api-max (= {max}), '
             'pypy3-cffi-backend-api-{target}\n'.format(**subst))
 
-with codecs.open('debian/pypy3.substvars', 'a', encoding='UTF-8') as f:
+with open('debian/pypy3.substvars', 'a', encoding='UTF-8') as f:
     f.write('pypy3-abi={}\n'.format(pypy_abi()))
 
 path = 'debian/pypy3-lib/usr/share/python3/dist'
 os.makedirs(path)
-with codecs.open(os.path.join(path, 'pypy3-cffi'), 'w', encoding='UTF-8') as f:
+with open(os.path.join(path, 'pypy3-cffi'), 'w', encoding='UTF-8') as f:
     f.write('cffi pypy3-cffi-backend-api-min (<= {target}), '
             'pypy3-cffi-backend-api-max (>= {target})\n'
             .format(**subst))
