@@ -101,15 +101,34 @@ if dpkg-architecture -iany-s390x; then
 	fi
 fi
 
-if echo "$PYTHON" | grep -Fq pypy; then
+if [ "$PYTHON" = "pypy" ]; then
 	if [ $(dpkg-architecture -q DEB_HOST_ARCH_BITS) -eq 32 ]; then
 		export PYPY_GC_MAX_DELTA=200MB
 		PYTHON="$PYTHON --jit loop_longevity=300"
 	fi
 fi
 
-RPYTHON="$(pwd)/rpython/bin/rpython"
+CURDIR=$(pwd)
+RPYTHON=$CURDIR/rpython/bin/rpython
+TMPDIR=$CURDIR/build-tmp
+PYPY_USESSION_BASENAME=debian
+C_SRC_DIR=$TMPDIR/usession-$PYPY_USESSION_BASENAME-0/testing_1
+SUB_MAKEFLAGS=$(echo ${DEB_BUILD_OPTIONS:-} | tr ' ' '\n' | sed -ne 's/parallel=/-j/p')
 
 set -x
+export TMPDIR PYPY_USESSION_BASENAME
+rm -rf "$TMPDIR"
+mkdir "$TMPDIR"
+
+export PYPY_MULTIARCH=$DEB_HOST_MULTIARCH
+
 cd pypy/goal
-exec $PYTHON -u $RPYTHON $RPYOPTS targetpypystandalone $TARGETOPTS 2>&1
+ln -s ../../lib_pypy/cffi/_pycparser/ pycparser
+$PYTHON -u $RPYTHON $RPYOPTS targetpypystandalone $TARGETOPTS 2>&1
+cd "$CURDIR"
+
+# PyPy captures all make output, so we call it ourselves (--source), to save
+# memory and avoid timeouts:
+make -C $C_SRC_DIR $SUB_MAKEFLAGS
+
+cp $C_SRC_DIR/pypy3-c $C_SRC_DIR/libpypy3-c.so pypy/goal
